package cn.com.infosec.jce.provider.symmetric;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.misc.CAST5CBCParameters;
import cn.com.infosec.crypto.CipherKeyGenerator;
import cn.com.infosec.crypto.engines.CAST5Engine;
import cn.com.infosec.crypto.modes.CBCBlockCipher;
import cn.com.infosec.jce.provider.JCEBlockCipher;
import cn.com.infosec.jce.provider.JCEKeyGenerator;
import cn.com.infosec.jce.provider.JDKAlgorithmParameterGenerator;
import cn.com.infosec.jce.provider.JDKAlgorithmParameters;
import java.io.IOException;
import java.security.AlgorithmParameters;
import java.security.InvalidAlgorithmParameterException;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import java.security.spec.InvalidParameterSpecException;
import javax.crypto.spec.IvParameterSpec;

public final class CAST5 {
   private CAST5() {
   }

   public static class AlgParamGen extends JDKAlgorithmParameterGenerator {
      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for CAST5 parameter generation.");
      }

      protected AlgorithmParameters engineGenerateParameters() {
         byte[] var1 = new byte[8];
         if (super.random == null) {
            SecureRandom var2;
            var2 = new SecureRandom.<init>();
            super.random = var2;
         }

         super.random.nextBytes(var1);

         try {
            AlgorithmParameters var10000 = AlgorithmParameters.getInstance("CAST5", "INFOSEC");
            var10000.init(new IvParameterSpec(var1));
            return var10000;
         } catch (Exception var3) {
            throw new RuntimeException(var3.getMessage());
         }
      }
   }

   public static class AlgParams extends JDKAlgorithmParameters {
      private byte[] iv;
      private int keyLength = 128;

      protected byte[] engineGetEncoded() {
         byte[] var1;
         byte[] var2;
         byte[] var10000 = var1 = new byte[(var2 = this.iv).length];
         byte[] var10001 = var2;
         int var3 = var2.length;
         System.arraycopy(var10001, 0, var1, 0, var3);
         return var10000;
      }

      protected byte[] engineGetEncoded(String format) {
         if (this.isASN1FormatString(format)) {
            AlgParams var10002 = this;
            byte[] var2 = this.engineGetEncoded();
            return (new CAST5CBCParameters(var2, var10002.keyLength)).getEncoded();
         } else {
            return format.equals("RAW") ? this.engineGetEncoded() : null;
         }
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         if (paramSpec == IvParameterSpec.class) {
            return new IvParameterSpec(this.iv);
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to CAST5 parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof IvParameterSpec) {
            this.iv = ((IvParameterSpec)paramSpec).getIV();
         } else {
            throw new InvalidParameterSpecException("IvParameterSpec required to initialise a CAST5 parameters algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         byte[] var10000 = params;
         byte[] var10001 = params = new byte[params.length];
         this.iv = params;
         int var2 = var10001.length;
         System.arraycopy(var10000, 0, params, 0, var2);
      }

      protected void engineInit(byte[] params, String format) {
         if (this.isASN1FormatString(format)) {
            AlgParams var10000 = this;
            CAST5CBCParameters var3;
            this.keyLength = (var3 = CAST5CBCParameters.getInstance((new ASN1InputStream(params)).readObject())).getKeyLength();
            var10000.iv = var3.getIV();
         } else if (format.equals("RAW")) {
            this.engineInit(params);
         } else {
            throw new IOException("Unknown parameters format in IV parameters object");
         }
      }

      protected String engineToString() {
         return "CAST5 Parameters";
      }
   }

   public static class CBC extends JCEBlockCipher {
      public CBC() {
         CBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         CAST5Engine var1;
         var1 = new CAST5Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   public static class ECB extends JCEBlockCipher {
      public ECB() {
         ECB var10000 = this;
         CAST5Engine var1;
         var1 = new CAST5Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class KeyGen extends JCEKeyGenerator {
      public KeyGen() {
         KeyGen var10000 = this;
         CipherKeyGenerator var1;
         var1 = new CipherKeyGenerator.<init>();
         var10000.<init>("CAST5", 128, var1);
      }
   }
}
